<?php

namespace App\Controller\Admin\System;

use App\Bundles\Sg\DatatablesBundle\Response\DatatableResponse;
use App\Controller\Admin\BaseController;
use App\Datatables\EventLogDatatable;
use App\Entity\EventType;
use Doctrine\Persistence\ManagerRegistry;
use Sg\DatatablesBundle\Datatable\DatatableFactory;
use Sg\DatatablesBundle\Datatable\DatatableInterface;
use Sg\DatatablesBundle\Response\DatatableQueryBuilder;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\Routing\Annotation\Route;
use Symfony\Component\HttpFoundation\Response;

class EventLogController extends BaseController
{
    /**
     * @Route("/admin/event-log", name="admin_event_log")
     * @param Request $request
     * @param ManagerRegistry $managerRegistry
     * @param DatatableFactory $factory
     * @param DatatableResponse $responseService
     * @return Response
     * @throws \Exception
     */
    public function default(Request $request, ManagerRegistry $managerRegistry,
                            DatatableFactory $factory, DatatableResponse $responseService): Response{

        $isAjax = $request->isXmlHttpRequest();
        $this->filter = $request->query->get('column');

        $eventTypes = $managerRegistry->getRepository(EventType::class)->findAll();

        /** @var DatatableInterface $datatable */
        $datatable = $factory->create(EventLogDatatable::class);
        $datatable->buildDatatable(['eventTypes' => $eventTypes]);

        if ($isAjax) {
            $responseService->setDatatable($datatable);

            $requestParams = $this->getDatatableFilter($request, $datatable);
            $datatableQueryBuilder = new DatatableQueryBuilder($requestParams, $datatable);
            $responseService->setDatatableQueryBuilder($datatableQueryBuilder);

            return $responseService->getResponse();
        }

        return $this->render('system/eventLog.html.twig', array(
            'datatable' => $datatable,
            'filter' => $this->filter,
        ));

    }

}