<?php

declare(strict_types=1);

namespace App\Entity;

use Doctrine\Common\Collections\Collection;
use Doctrine\ORM\Mapping as ORM;

/**
 * @ORM\Entity
 * @ORM\Table(name="user_modules")
 */
class UserModule
{
    /**
     * @var int|null
     * @ORM\Column(type="integer")
     * @ORM\Id
     * @ORM\GeneratedValue(strategy="AUTO")
     */
    private ?int $id = null;

    /**
     * @var Collection
     * @ORM\OneToMany (targetEntity="App\Entity\DeviceUserModule", mappedBy="userModule", cascade={"persist"})
     * @ORM\JoinColumn(name="id")
     */
    public Collection $userModules;

    /**
     * @var string
     * @ORM\Column(name="name", type="string", length=128, nullable=false)
     */
    public string $name;

    /**
     * @var string
     * @ORM\Column(name="versionstring", type="string", length=64, nullable=true)
     */
    public string $version;

    /**
     * @var bool
     * @ORM\Column(type="boolean", options={"default": 0})
     */
    public bool $internal = false;

    /**
     * @var bool
     * @ORM\Column(type="boolean", options={"default": 0})
     */
    public bool $available = false;

    /**
     * @var bool
     * @ORM\Column(type="boolean", options={"default": 0})
     */
    public bool $approved = false;

    /**
     * @var bool
     * @ORM\Column(type="boolean", options={"default": 0})
     */
    public bool $hidden = false;


    /**
     * @return int|null
     */
    public function getId(): ?int
    {
        return $this->id;
    }

    /**
     * @return string
     */
    public function getName(): string
    {
        return $this->name;
    }

    /**
     * @return string
     */
    public function getVersion(): string {

        return $this->version;

    }

    /**
     * @return bool
     */
    public function isHidden(): bool
    {
        return $this->hidden;
    }

    /**
     * @return bool
     */
    public function isInternal(): bool
    {
        return $this->internal;
    }

    /**
     * @return bool
     */
    public function isAvailable(): bool
    {
        return $this->available;
    }

    /**
     * @return bool
     */
    public function isApproved(): bool
    {
        return $this->approved;
    }

    /**
     * @return string
     */
    public function __toString(): string {

        return $this->getVersion();

    }

}